@@ -339,9 +339,9 @@ class Network(object):
         self._route_state = None
         self._dns_state = None
 
+        self._create_dns()
         self._create_interfaces_state()
         self._create_routes()
-        self._create_dns()
 
     @property
     def name(self):
@@ -408,6 +408,10 @@ class Network(object):
     def purge_old_base_iface(self):
         return self._remove_vlan_iface()
 
+    @property
+    def _auto_dns(self):
+        return self.default_route and not self.dns_state
+
     def _create_dns(self):
         """
         The DNS state may include one of the following outputs:
@@ -538,7 +542,7 @@ class Network(object):
     def _create_dynamic_ipv4(self):
         return {
             InterfaceIP.DHCP: self._netconf.dhcpv4,
-            InterfaceIP.AUTO_DNS: self.default_route,
+            InterfaceIP.AUTO_DNS: self._auto_dns,
             InterfaceIP.AUTO_GATEWAY: self.default_route,
             InterfaceIP.AUTO_ROUTES: self.default_route,
         }
@@ -571,7 +575,7 @@ class Network(object):
         return {
             InterfaceIP.DHCP: self._netconf.dhcpv6,
             InterfaceIPv6.AUTOCONF: self._netconf.ipv6autoconf,
-            InterfaceIP.AUTO_DNS: self.default_route,
+            InterfaceIP.AUTO_DNS: self._auto_dns,
             InterfaceIP.AUTO_GATEWAY: self.default_route,
             InterfaceIP.AUTO_ROUTES: self.default_route,
         }
